@@ -24,9 +24,9 @@ class VerifyReferenceOfByUserId(ConsumeAction):
         namespace_name: str,
         inventory_name: str,
         item_name: str,
-        item_set_name: str,
         reference_of: str,
         verify_type: str,
+        item_set_name: Optional[str] = None,
         user_id: Optional[str] = "#{userId}",
     ):
         properties: Dict[str, Any] = {}
@@ -34,9 +34,9 @@ class VerifyReferenceOfByUserId(ConsumeAction):
         properties["namespaceName"] = namespace_name
         properties["inventoryName"] = inventory_name
         properties["itemName"] = item_name
-        properties["itemSetName"] = item_set_name
         properties["referenceOf"] = reference_of
         properties["verifyType"] = verify_type
+        properties["itemSetName"] = item_set_name
         properties["userId"] = user_id
 
         super().__init__(
